@@ -15,7 +15,7 @@ pub const SRTCP_BUFFER_SIZE: usize = 100 * 1000;
 pub struct Stream {
     ssrc: u32,
     tx: mpsc::Sender<u32>,
-    buffer: Buffer,
+    pub(crate) buffer: Buffer,
     is_rtp: bool,
 }
 
@@ -38,11 +38,6 @@ impl Stream {
         }
     }
 
-    /// Get Cloned Buffer
-    pub(crate) fn get_cloned_buffer(&self) -> Buffer {
-        self.buffer.clone()
-    }
-
     /// GetSSRC returns the SSRC we are demuxing for
     pub fn get_ssrc(&self) -> u32 {
         self.ssrc
